@@ -331,7 +331,7 @@ void KSMainWindow::moveEvent(QMoveEvent *event)
 // slots
 void KSMainWindow::captureScreenshot(Spectacle::CaptureMode theCaptureMode, int theTimeout, bool theIncludePointer, bool theIncludeDecorations)
 {
-    if (theTimeout < 0) { // OnClick is checked (always the case on Wayland)
+    if (theTimeout <= 0) { // OnClick is checked (always the case on Wayland)
         hide();
         Q_EMIT newScreenshotRequest(theCaptureMode, theTimeout, theIncludePointer, theIncludeDecorations);
         return;
