@@ -6,10 +6,10 @@
  */
 
 #include "Config.h"
-#include "settings.h"
 #include "SpectacleCommon.h"
 #include "SpectacleCore.h"
 #include "SpectacleDBusAdapter.h"
+#include "settings.h"
 
 #ifdef KIMAGEANNOTATOR_CAN_LOAD_TRANSLATIONS
 #include <kImageAnnotator/KImageAnnotator.h>
@@ -18,6 +18,7 @@
 #include <QApplication>
 #include <QCommandLineParser>
 #include <QDBusConnection>
+#include <QSessionManager>
 
 #include <KAboutData>
 #include <KDBusService>
@@ -27,11 +28,12 @@ int main(int argc, char **argv)
 {
     // set up the application
 
+    QCoreApplication::setAttribute(Qt::AA_DontCreateNativeWidgetSiblings);
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+    QCoreApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
+#endif
     QApplication app(argc, argv);
 
-    app.setAttribute(Qt::AA_DontCreateNativeWidgetSiblings, true);
-    app.setAttribute(Qt::AA_UseHighDpiPixmaps, true);
-
     KLocalizedString::setApplicationDomain("spectacle");
     QCoreApplication::setOrganizationDomain(QStringLiteral("org.kde"));
 
@@ -56,9 +58,17 @@ int main(int argc, char **argv)
     // first parsing for help-about
     lCmdLineParser.process(app.arguments());
     aboutData.processCommandLine(&lCmdLineParser);
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+    QGuiApplication::setFallbackSessionManagementEnabled(false);
+#endif
+    auto disableSessionManagement = [](QSessionManager &sm) {
+        sm.setRestartHint(QSessionManager::RestartNever);
+    };
+    QObject::connect(&app, &QGuiApplication::commitDataRequest, disableSessionManagement);
+    QObject::connect(&app, &QGuiApplication::saveStateRequest, disableSessionManagement);
 
     // and new-instance
-    if (lCmdLineParser.isSet(QStringLiteral("new-instance"))){
+    if (lCmdLineParser.isSet(QStringLiteral("new-instance"))) {
         lCore.init();
 
         QObject::connect(&lCore, &SpectacleCore::allDone, &app, &QCoreApplication::quit, Qt::QueuedConnection);
